/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.pool.api;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * This interafece contains the accessor methods (getters and setters) which
 * permit to tune a Pool:
 * <ul>
 * <li>
 * A <b>Timeout</b> can be assigned to a Pool. It is used when no more
 * PoolResource is available and when the Pool has reached its maximum size.
 * This is the timeout to wait for a free PoolResource until exting with an
 * exception. It defaults to 0, which means waiting forever until a
 * PoolResource is freed. Its value should be greater or equal to 0 ; negative
 * values are ignored (setTimeOut(-1) => NOP).
 * </li>
 * <li>
 * A <b>MinSize</b> can be assigned to a Pool. Its value should be greater or
 * equal to 0, and smaller or equal to MaxSize. Values that do not match these
 * conditions are ignored (e.g., setMinSize(-1) => NOP).
 * This size means that there is always MinSize PoolResource allocated in this
 * Pool. If PoolResource needs to be allocated when setting this size,
 * "getPoolMatchFactory().createResource(null)" is called. Its default value
 * is 0.
 * </li>
 * <li>
 * A <b>MaxSize</b> can be assigned to a Pool. Its value should be greater or
 * equal to 0, and greater or equal to MinSize. Values that do not match these
 * conditions are ignored (e.g., setMaxSize(-1) => NOP). Its default value
 * is 0, thus it is mandatory to set this value for making the Poll functional.
 * </li>
 * </ul>
 *
 * @author S.Chassande-Barrioz
 */
public interface PoolAttributes extends AttributeController {


    /**
	 * <b>getTimeout</b> retrieves the timeout assigned to this Pool.
	 * @return	The timeout currently assigned to this Pool.
	 */
	long getTimeout();

	/**
	 * <b>getMinSize</b> retrieves the minimum size assigned to this Pool.
	 * @return	The minimum size currently assigned to this Pool.
	 */
	int getMinSize();

	/**
	 * <b>getMaxSize</b> retrieves the maximum size assigned to this Pool.
	 * @return	The maximum size currently assigned to this Pool.
	 */
	int getMaxSize();

	/**
	 * <b>getTTL</b> retrieves the time to live of pool
	 * resources (in milisecond).
	 */
	long getTTL();

	/**
	 * <b>getTTL</b> retrieves the time to live of pool
	 * resources when they are unused (in milisecond).
	 */
	long getInactiveTTL();

	/**
	 * <b>setTimeout</b> assigns a timeout to this Pool.
	 * @param crto		The timeout to be assigned.
	 */
	void setTimeout(long crto);

	/**
	 * <b>setMinSize</b> assigns a minimum size to this Pool.
	 * @param minsize	The minimum size to be assigned.
	 */
	void setMinSize(int minsize) throws Exception;

	/**
	 * <b>setMaxSize</b> assigns a maximum size to this Pool.
	 * @param maxsize	The maximum size to be assigned.
	 */
	void setMaxSize(int maxsize) throws Exception;

	/**
	 * <b>setTTL</b> assignes the time (in milisecond) to live of pool
	 * resources. If the value is lesser or equal to 0 then pool resources do
	 * not have a TTL.
	 */
	void setTTL(long ttl);

	/**
	 * <b>setTTL</b> assignes the time (in milisecond) to live of pool
	 * resources when they are unused. If the value is lesser or equal to 0 
	 * then pool resources do not have a TTL.
	 */
	void setInactiveTTL(long ttl);

}
